Crate kcr_chaos_mesh_org

Crate kcr_chaos_mesh_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the chaos-mesh.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

chaos-mesh.org/v1alpha1

  • AWSChaos
  • AzureChaos
  • BlockChaos
  • DNSChaos
  • GCPChaos
  • HTTPChaos
  • IOChaos
  • JVMChaos
  • KernelChaos
  • NetworkChaos
  • PhysicalMachineChaos
  • PhysicalMachine
  • PodChaos
  • PodHttpChaos
  • PodIOChaos
  • PodNetworkChaos
  • RemoteCluster
  • Schedule
  • StatusCheck
  • StressChaos
  • TimeChaos
  • WorkflowNode
  • Workflow

Modules

v1alpha1