This crate contains kube-rs compatible bindings for Kubernetes custom resources for the chaos-mesh.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
chaos-mesh.org/v1alpha1
AWSChaosAzureChaosBlockChaosDNSChaosGCPChaosHTTPChaosIOChaosJVMChaosKernelChaosNetworkChaosPhysicalMachineChaosPhysicalMachinePodChaosPodHttpChaosPodIOChaosPodNetworkChaosRemoteClusterScheduleStatusCheckStressChaosTimeChaosWorkflowNodeWorkflow